@@ -1,4 +1,5 @@
-from .errors import (ApiError, ApiClientError, MangaError, TagError, ChapterError, AuthorError, ScanlationGroupError, UserError, CustomListError, CoverArtError)
+from .errors import (ApiError, ApiClientError, MangaError, TagError, ChapterError, \
+                    AuthorError, ScanlationGroupError, UserError, CustomListError, CoverArtError)
 
 from .url_models import (URLRequest)
 
@@ -7,6 +8,6 @@ from .models import (Manga, Tag, Chapter, User, ScanlationGroup, Author, CustomL
 from .api import (Api)
 
 __author__ = 'Eduardo Ceja'
-__version__ = "2.3.3"
+__version__ = "2.5.1"
 __license__ = "MIT"
-__copytight__ = "Copyright (c) 2021 Eduardo Ceja"
\ No newline at end of file
+__copytight__ = "Copyright (c) 2021 Eduardo Ceja"
