@@ -1,26 +1,25 @@
-from __future__ import absolute_import
-
-from typing import Dict, Tuple, List, Union
-
-from mangadex import (Manga, Tag, Chapter, User, UserError, ChapterError, Author, ScanlationGroup, CoverArt, CustomList, URLRequest, TagError)
-
+"""
+"""
 import re #for validating email and prevent spam
-
+from __future__ import absolute_import
+from typing import Dict, List, Union
+from mangadex import (Manga, Tag, Chapter, User, UserError, ChapterError,
+                    Author, ScanlationGroup, CoverArt, CustomList, URLRequest, TagError)
 class Api():
     def __init__(self, timeout = 5):
         self.URL = 'https://api.mangadex.org'
         self.bearer = None
         self.timeout = timeout
 
-    def _auth_handler(self, json_payload) -> None:
+    def __auth_handler(self, json_payload) -> None:
         url = f"{self.URL}/auth/login"
-        auth = URLRequest._request_url(url, "POST", params = json_payload, timeout=self.timeout)
+        auth = URLRequest.request_url(url, "POST", params = json_payload, timeout=self.timeout)
         token = auth['token']['session']
         bearer = {"Authorization" : f"Bearer {token}"}
         self.bearer = bearer
 
     @staticmethod
-    def _parse_manga_params(params : dict) -> dict:
+    def __parse_manga_params(params : dict) -> dict:
         if "authors" in params:
             temp = params.pop("authors")
             params["authors[]"] = temp
@@ -78,9 +77,9 @@ class Api():
         authors : `List[str]`
         artist : `List[str]`
         year : `int`
-        includedTags : `List[str]`
+        includedTags : `List[Tag.id]`
         includedTagsMode: `str`. Default `"AND"`. Enum: `"AND"` `"OR"`
-        excludedTags : `List[str]`
+        excludedTags : `List[Tag.id]`
         exludedTagsMode : `str`. Default `"AND"`, Enum : `"AND"`, `"OR"`
         status : `List[str]`. Items Enum : `"ongoing"`, `"completed"`, `"hiatus"`, `"cancelled"`
         originalLanguage : `List[str]`
@@ -89,30 +88,28 @@ class Api():
         contentRating : `List[str]`. Items Enum : `"safe"` `"suggestive"` `"erotica"` `"pornographic"`
         createdAtSince : `str`. Datetime String with the following format YYYY-MM-DDTHH:MM:SS
         updatedAtSince : `str`. Datetime String with the following format YYYY-MM-DDTHH:MM:SS
-        
+
         Returns
         -------------
         `List[Manga]`. A list of Manga objects
 
         Raises
         -------------
-        `ApiError`
-
-        `MangaError`
-        """            
+        `ApiError` `MangaError`
+        """
         params = kwargs
-        params = Api._parse_manga_params(params)
+        params = Api.__parse_manga_params(params)
         url = f"{self.URL}/manga"
-        resp = URLRequest._request_url(url, 'GET', params=params, timeout=self.timeout)
-        return Manga._create_manga_list(resp)
+        resp = URLRequest.request_url(url, 'GET', params=params, timeout=self.timeout)
+        return Manga.create_manga_list(resp)
 
-    def view_manga_by_id(self, id: str)-> Manga:
+    def view_manga_by_id(self, manga_id: str)-> Manga:
         """
         Get a Manga by its id
 
         Parameters
         ------------
-        id: `str`. The manga id
+        manga_id: `str`. The manga id
 
         Returns
         -------------
@@ -120,14 +117,12 @@ class Api():
 
         Raises
         ------------
-        `ApiError`
-
-        `MangaError`
+        `ApiError` `MangaError`
         """
-        url = f"{self.URL}/manga/{id}"
-        resp = URLRequest._request_url(url, "GET", timeout=self.timeout)
-        return Manga._create_manga(resp)
-    
+        url = f"{self.URL}/manga/{manga_id}"
+        resp = URLRequest.request_url(url, "GET", timeout=self.timeout)
+        return Manga.MangaFromDict(resp)
+
     def random_manga(self) -> Manga:
         """
         Get a random Manga
@@ -138,13 +133,11 @@ class Api():
 
         Raises
         ----------
-        `ApiError`
-
-        `MangaError`
+        `ApiError` `MangaError`
         """
         url = f"{self.URL}/manga/random"
-        resp = URLRequest._request_url(url, "GET", timeout=self.timeout)
-        return Manga._create_manga(resp)
+        resp = URLRequest.request_url(url, "GET", timeout=self.timeout)
+        return Manga.MangaFromDict(resp)
 
     def create_manga(self, title : str, **kwargs) -> Manga:
         """
@@ -159,7 +152,8 @@ class Api():
         description : `Dict[str,str]`. The alt titles in different languages
         authors : `List[str]`. The list of author id's
         artists : `List[str]`. The list of artist id's
-        links : `Dict[str,str]`. The links in differents sites (al, ap, bw, mu, etc). Please refer to the [documentation](https://api.mangadex.org/docs.html#section/Static-data/Manga-links-data)
+        links : `Dict[str,str]`. The links in differents sites (al, ap, bw, mu, etc).
+        Please refer to the [documentation](https://api.mangadex.org/docs.html#section/Static-data/Manga-links-data)
         originalLanguage : `str`. The original Language
         lastVolume : `str`. The last volume
         lastChapter : `str`. The last chapter
@@ -173,19 +167,19 @@ class Api():
         ------------
         `Manga`. A manga object if `ObjReturn` is set to `True`
         """
-        params = self._parse_manga_params(kwargs)
+        params = self.__parse_manga_params(kwargs)
         url = f"{self.URL}/manga"
         params["title"] = title
-        resp = URLRequest._request_url(url, "POST", params=params, headers=self.bearer, timeout = self.timeout)
-        return  Manga._create_manga(resp)
+        resp = URLRequest.request_url(url, "POST", params=params, headers=self.bearer, timeout = self.timeout)
+        return  Manga.MangaFromDict(resp)
 
-    def get_manga_volumes_and_chapters(self, id : str, **kwargs) -> Dict[str, str]:
+    def get_manga_volumes_and_chapters(self, manga_id : str, **kwargs) -> Dict[str, str]:
         """
         Get a manga volumes and chapters
 
         Parameters
         ------------
-        id : `str`. The manga id
+        manga_id : `str`. The manga id
         translatedLanguage : `List[str]`
 
         Returns
@@ -195,18 +189,18 @@ class Api():
         params = None
         if "translatedLanguage" in kwargs:
             params = {"translatedLanguage[]" : kwargs["translatedLanguage"]}
-        url = f"{self.URL}/manga/{id}/aggregate"
-        resp = URLRequest._request_url(url, "GET", timeout = self.timeout, params = params)
+        url = f"{self.URL}/manga/{manga_id}/aggregate"
+        resp = URLRequest.request_url(url, "GET", timeout = self.timeout, params = params)
         return resp["volumes"]
 
-    def update_manga(self, id : str, ObjReturn : bool = False ,**kwargs) -> Manga:
+    def update_manga(self, manga_id : str, ObjReturn : bool = False ,**kwargs) -> Manga:
         """
         Updates a manga parameters
 
         Parameters
         -------------
         ### Required parameters
-        id : `str`. The manga id
+        manga_id : `str`. The manga id
         version : `int`
         ObjReturn : `bool`. `True` if you want a Manga Object return
 
@@ -230,40 +224,41 @@ class Api():
         ------------
         `Manga`. A manga object if `ObjReturn` is set to `True`
         """
-        kwargs = self._parse_manga_params(kwargs)
-        url = f"{self.URL}/manga/{id}"
-        resp = URLRequest._request_url(url, "PUT", params=kwargs, headers=self.bearer, timeout=self.timeout)
+        kwargs = self.__parse_manga_params(kwargs)
+        url = f"{self.URL}/manga/{manga_id}"
+        resp = URLRequest.request_url(url, "PUT", params=kwargs, headers=self.bearer, timeout=self.timeout)
         if ObjReturn:
-            return Manga._create_manga(resp)
-    
-    def delete_manga(self, id : str) -> None:
+            return Manga.MangaFromDict(resp)
+        return None
+
+    def delete_manga(self, manga_id : str) -> None:
         """
         Deletes a manga
-        
+
         Parameters
         ------------
         id : `str`. The manga id
-
         """
-        url = f"{self.URL}/manga{id}"
-        URLRequest._request_url(url, "DELETE", headers=self.bearer, timeout= self.timeout)
+        url = f"{self.URL}/manga{manga_id}"
+        URLRequest.request_url(url, "DELETE", headers=self.bearer, timeout= self.timeout)
 
-    def get_manga_read_markes(self, id : str) -> List[Chapter]: # this needs a performance update
+    def get_manga_read_markes(self, manga_id : str) -> List[Chapter]:
+        # this needs a performance update
         """
         A list of Chapter Id's That are marked fro the given manga Id
-        
+
         Parameters
         ------------
-        id : `str`. The Manga id
+        manga_id : `str`. The Manga id
 
         Returns
         -------------
         `List[Chapters]`. A list of chapters that are marked as read
         """
-        url = f"{self.URL}/manga/{id}/read"
-        resp = URLRequest._request_url(url, "GET", timeout= self.timeout ,headers=self.bearer)
+        url = f"{self.URL}/manga/{manga_id}/read"
+        resp = URLRequest.request_url(url, "GET", timeout= self.timeout ,headers=self.bearer)
         chap_ids = resp["data"]
-        return [self.get_chapter(chap) for chap in chap_ids] # I think this is 
+        return [self.get_chapter(chap) for chap in chap_ids]
 
     def tag_list(self) -> List[Tag]:
         """
@@ -275,21 +270,19 @@ class Api():
 
         Raises
         -----------
-        `ApiError`
-
-        `TagError`
+        `ApiError` `TagError`
         """
         url = f"{self.URL}/manga/tag"
-        resp = URLRequest._request_url(url, "GET", timeout = self.timeout)
-        return Tag._create_tag_list(resp)
-    
-    def manga_feed(self, id : str, **kwargs) -> List[Chapter]:
+        resp = URLRequest.request_url(url, "GET", timeout = self.timeout)
+        return Tag.create_tag_list(resp)
+
+    def manga_feed(self, manga_id : str, **kwargs) -> List[Chapter]:
         """
         Get the manga feed
 
         Parameters
         ------------
-        id `str`, Required. The manga id
+        manga_id `str`, Required. The manga id
 
         ### QueryParams:
 
@@ -305,17 +298,15 @@ class Api():
 
         Raises
         -------------
-        `ApiError`
-
-        `ChapterError`
+        `ApiError` `ChapterError`
         """
-        kwargs = self._parse_manga_params(kwargs)
-        url = f"{self.URL}/manga/{id}/feed"
-        resp = URLRequest._request_url(url, "GET", timeout = self.timeout, params = kwargs)
-        return Chapter._create_chapter_list(resp)
+        kwargs = self.__parse_manga_params(kwargs)
+        url = f"{self.URL}/manga/{manga_id}/feed"
+        resp = URLRequest.request_url(url, "GET", timeout = self.timeout, params = kwargs)
+        return Chapter.create_chapter_list(resp)
 
     @staticmethod
-    def _parse_chapter_list_args(params : Dict[str, str]) -> Dict[str,str]:
+    def __parse_chapter_list_args(params : Dict[str, str]) -> Dict[str,str]:
         if "groups" in params:
             params["groups[]"] =  params.pop("groups")
         if "volume" in params:
@@ -327,7 +318,8 @@ class Api():
 
     def chapter_list(self, **kwargs) -> List[Chapter]:
         """
-        The list of chapters. To get the chpaters of a specific manga the manga parameter must be provided
+        The list of chapters.
+        To get the chpaters of a specific manga the manga parameter must be provided
 
         Parameters
         -----------
@@ -337,7 +329,7 @@ class Api():
         offset : `int`
         title : `str`
         groups : `List[str]`
-        uploader : `str`    
+        uploader : `str`
         manga : `str`
         volume : `str | List[str]`
         chapter : `str`
@@ -352,15 +344,14 @@ class Api():
 
         Raises
         -------------
-        `ApiError` \n
-        `ChapterError`
+        `ApiError` `ChapterError`
         """
-        params =  Api._parse_chapter_list_args(kwargs)
+        params =  Api.__parse_chapter_list_args(kwargs)
         url = f"{self.URL}/chapter"
-        resp = URLRequest._request_url(url, "GET", timeout= self.timeout, params= params)
-        return Chapter._create_chapter_list(resp)
+        resp = URLRequest.request_url(url, "GET", timeout= self.timeout, params= params)
+        return Chapter.create_chapter_list(resp)
 
-    def get_chapter(self, id: str) -> Chapter:
+    def get_chapter(self, chapter_id: str) -> Chapter:
         """
         Get a Chapter by its id
 
@@ -374,14 +365,12 @@ class Api():
 
         Raises
         ------------
-        `ApiError`
-
-        `ChapterError`
+        `ApiError` `ChapterError`
         """
-        url = f"{self.URL}/chapter/{id}"
-        resp = URLRequest._request_url(url, "GET", timeout = self.timeout)
-        return Chapter._create_chapter(resp)
-        
+        url = f"{self.URL}/chapter/{chapter_id}"
+        resp = URLRequest.request_url(url, "GET", timeout = self.timeout)
+        return Chapter.ChapterFromDict(resp)
+
     def get_author(self, **kwargs) -> List[Author]:
         """
         Get the author List
@@ -390,7 +379,7 @@ class Api():
         ------------
         limit : `int`
         offset : `int`
-        ids : List[`str`]. Array of ids 
+        ids : List[`str`]. Array of ids
         name : `str`
 
         Returns
@@ -399,23 +388,22 @@ class Api():
 
         Raises
         ------------
-        `ApiError` \n
-        `AuthorError`
+        `ApiError` `AuthorError`
         """
         if "ids" in kwargs:
             kwargs["ids[]"] = kwargs.pop("ids")
-        
-        url = f"{self.URL}/author"
-        resp = URLRequest._request_url(url, "GET", timeout=self.timeout ,params = kwargs)
-        return Author._create_authors_list(resp)
 
-    def get_author_by_id(self, id : str) -> Author:
+        url = f"{self.URL}/author"
+        resp = URLRequest.request_url(url, "GET", timeout=self.timeout ,params = kwargs)
+        return Author.AuthorFromDict(resp)
+
+    def get_author_by_id(self, author_id : str) -> Author:
         """
         Get's an author by its id
 
         Parameters
         -------------
-        id `str` The id of the author
+        author_id `str` The id of the author
 
         Returns
         ------------
@@ -423,12 +411,11 @@ class Api():
 
         Raises
         ------------
-        `ApiError` \n
-        `AuthorError`
+        `ApiError` `AuthorError`
         """
-        url = f"{self.URL}/author/{id}"
-        resp = URLRequest._request_url(url, "GET", timeout=self.timeout)
-        return Author._create_author(resp)
+        url = f"{self.URL}/author/{author_id}"
+        resp = URLRequest.request_url(url, "GET", timeout=self.timeout)
+        return Author.AuthorFromDict(resp)
 
     def create_author(self, name : str, version : int, ObjReturn : bool = False) -> Author:
         """
@@ -446,52 +433,52 @@ class Api():
         """
         url = f"{self.URL}/author"
         params = {"name" : name, "version" : version}
-        resp = URLRequest._request_url(url, "POST", timeout=self.timeout, params=params, headers=self.bearer)
+        resp = URLRequest.request_url(url, "POST", timeout=self.timeout, params=params, headers=self.bearer)
         if ObjReturn:
-            return Author._create_author(resp)
-    
-    def update_author(self, id : str, version : int, name : str = None, ObjReturn : bool = False) -> Author:
+            return Author.AuthorFromDict(resp)
+
+    def update_author(self, author_id : str, version : int, name : str = None, ObjReturn : bool = False) -> Author:
         """
         Updates an Author
 
         Parameters
         -------------
-        id : `str`. Required. The author id
+        author_id : `str`. Required. The author id
         version : `int`. Required
-        name : `str`. 
+        name : `str`.
         ObjReturn : `bool`.  `True` if you want a Author Object return
 
         Returns
         -----------
         `Author` if `ObjReturn` is `True`
         """
-        url = f"{self.URL}/author/{id}"
+        url = f"{self.URL}/author/{author_id}"
         params  = {"version" : version}
         if name is not None:
             params["name"] = name
-        resp = URLRequest._request_url(url, "PUT", timeout = self.timeout, params=params, headers=self.bearer)
+        resp = URLRequest.request_url(url, "PUT", timeout = self.timeout, params=params, headers=self.bearer)
 
         if ObjReturn:
-            return Author._create_author(resp)
-        
-    def delete_author(self, id : str) -> None:
+            return Author.AuthorFromDict(resp)
+
+    def delete_author(self, author_id : str) -> None:
         """
         Deletes an author
 
         Parameters
         ---------------
-        id : `str`. Required. The author id
+        author_id : `str`. Required. The author id
         """
-        url = f"{self.URL}/author/{id}"
-        URLRequest._request_url(url, "DELETE", headers=self.bearer)
+        url = f"{self.URL}/author/{author_id}"
+        URLRequest.request_url(url, "DELETE", headers=self.bearer, timeout= self.timeout)
 
-    def get_user(self, id : str) -> User:
+    def get_user(self, user_id : str) -> User:
         """
         Get User by its id
 
         Parameters
         ------------
-        id `str` The user id
+        user_id `str` The user id
 
         Returns
         ------------
@@ -502,11 +489,12 @@ class Api():
         `ApiError` \n
         `UserError`
         """
-        url = f"{self.URL}/user/{id}"
-        resp = URLRequest._request_url(url, "GET")
-        return User._create_user(resp)
-    
-    def scanlation_group_list(self, limit : int = None, offset : int = None, group_ids : List[str] = None, name : str = None) -> List[ScanlationGroup]:
+        url = f"{self.URL}/user/{user_id}"
+        resp = URLRequest.request_url(url, "GET", timeout = self.timeout)
+        return User.UserFromDict(resp)
+
+    def scanlation_group_list(self, limit : int = None, offset : int = None,
+                            group_ids : List[str] = None, name : str = None) -> List[ScanlationGroup]:
         """
         Get the scanlation groups list
 
@@ -533,9 +521,9 @@ class Api():
             params["ids[]"] = group_ids
         if name is not None:
             params["name"] = name
-        
-        resp = URLRequest._request_url(url, "GET", timeout = self.timeout ,params=params)
-        return ScanlationGroup._create_group_list(resp)
+
+        resp = URLRequest.request_url(url, "GET", timeout = self.timeout ,params=params)
+        return ScanlationGroup.create_group_list(resp)
 
     def login(self, username : str, password : str):
         """
@@ -550,19 +538,19 @@ class Api():
         ---------------
         `ApiError`
         """
-        self._auth_handler(json_payload= {"username" : username, "password" : password})
+        self.__auth_handler(json_payload= {"username" : username, "password" : password})
 
     def me(self) -> User:
         """
         Get your user info
 
-        Return
+        Returns
         ---------
         `User`
         """
         url = f"{self.URL}/user/me"
-        resp = URLRequest._request_url(url, "GET", timeout = self.timeout, headers = self.bearer)
-        return User._create_user(resp)
+        resp = URLRequest.request_url(url, "GET", timeout = self.timeout, headers = self.bearer)
+        return User.UserFromDict(resp)
 
     def get_my_mangalist(self, **kwargs) -> List[Manga]:
         """
@@ -571,7 +559,6 @@ class Api():
         Parameters
         -------------
         limit `int`
-
         offset `int`
 
         Returns
@@ -579,9 +566,9 @@ class Api():
         `List[Manga]`
         """
         url = f"{self.URL}/user/follows/manga"
-        resp = URLRequest._request_url(url, "GET", timeout= self.timeout, params = kwargs, headers=self.bearer)
-        return Manga._create_manga_list(resp)
-    
+        resp = URLRequest.request_url(url, "GET", timeout= self.timeout, params = kwargs, headers=self.bearer)
+        return Manga.create_manga_list(resp)
+
     def get_my_followed_groups(self, **kwargs) -> List[ScanlationGroup]:
         """
         Get the Scanlination Groups you follow
@@ -589,19 +576,18 @@ class Api():
         Parameters
         -------------
         limit `int`
-
         offset `int`
-
         translatedLanguage : `List[str]`
+
         Returns
         -------------
         `List[ScanlationGroup]`
         """
-        if "translatedLanguage" in kwargs: 
+        if "translatedLanguage" in kwargs:
             kwargs['translatedLanguage[]'] = kwargs.pop("translatedLanguage")
         url = f"{self.URL}/user/follows/group"
-        resp = URLRequest._request_url(url, "GET", timeout = self.timeout,  params=kwargs, headers= self.bearer)
-        return ScanlationGroup._create_group_list(resp)
+        resp = URLRequest.request_url(url, "GET", timeout = self.timeout,  params=kwargs, headers= self.bearer)
+        return ScanlationGroup.create_group_list(resp)
 
     def get_my_followed_users(self, **kwargs) -> List[User]:
         """
@@ -610,7 +596,6 @@ class Api():
         Parameters
         -------------
         limit : `int`
-
         offset : `int`
 
         Returns
@@ -618,23 +603,23 @@ class Api():
         `List[User]`
         """
         url = f"{self.URL}/user/follows/user"
-        resp = URLRequest._request_url(url, "GET", timeout= self.timeout ,params=kwargs, headers=self.bearer)
-        return User._create_user_list(resp)
+        resp = URLRequest.request_url(url, "GET", timeout= self.timeout ,params=kwargs, headers=self.bearer)
+        return User.create_user_list(resp)
 
-    def get_manga_reading_status(self, id : str) -> str:
+    def get_manga_reading_status(self, manga_id : Union[str, int]) -> str:
         """
         Get a manga reading status given its id
 
         Parameters
         ------------
-        id : `str`. The manga id
+        manga_id : `str`. The manga id
 
         Returns
         ------------
         `str` The manga reading status
         """
-        url = f"{self.URL}/manga/{id}/status"
-        resp = URLRequest._request_url(url, "GET", headers=self.bearer, timeout=self.timeout)
+        url = f"{self.URL}/manga/{manga_id}/status"
+        resp = URLRequest.request_url(url, "GET", headers=self.bearer, timeout=self.timeout)
         return resp["status"]
 
     def get_all_manga_reading_status(self, status : str = None) -> Dict[str, str]:
@@ -650,70 +635,68 @@ class Api():
         `Dict[str,str]` A dictionary with the Manga id and its status
         """
         url = f"{self.URL}/manga/status"
-        resp = URLRequest._request_url(url, "GET", params={"status": status}, headers=self.bearer, timeout= self.timeout)
+        resp = URLRequest.request_url(url, "GET", params={"status": status}, headers=self.bearer, timeout= self.timeout)
         return resp["statuses"]
-    
-    def follow_manga(self, id  : str) -> None:
+
+    def follow_manga(self, manga_id : Union [str, int]) -> None:
         """
         Follow a manga
 
         Parameters
         --------------
-
-        id : `str`. The manga id
+        manga_id : `str`. The manga id
 
         Raises
         -------------
         `ApiError`
         """
-        url = f"{self.URL}/manga/{id}/follow"
-        URLRequest._request_url(url, "POST", headers=self.bearer, timeout=self.timeout)
-    
-    def unfollow_manga(self, id : str) -> None:
+        url = f"{self.URL}/manga/{manga_id}/follow"
+        URLRequest.request_url(url, "POST", headers=self.bearer, timeout=self.timeout)
+
+    def unfollow_manga(self, manga_id : str) -> None:
         """
         Unfollows a Manga
 
         Parameters
         -------------
-        id : `str`. The manga id
+        manga_id : `str`. The manga id
 
         Raises
         -----------
         `ApiError`
         """
-        url = f"{self.URL}/manga/{id}/follow"
-        URLRequest._request_url(url, "DELETE", headers=self.bearer, timeout=self.timeout)
+        url = f"{self.URL}/manga/{manga_id}/follow"
+        URLRequest.request_url(url, "DELETE", headers=self.bearer, timeout=self.timeout)
 
-    def update_manga_reading_status(self, id : str, status : str ) -> None:
+    def update_manga_reading_status(self, manga_id : str, status : str ) -> None:
         """
         Update the reading stauts of a manga
 
         Parameters
         -------------
-
-        id : `str`. The manga id
+        manga_id : `str`. The manga id.\n
         status : `str`. Values : `"reading"` `"on_hold"` `"plan_to_read"` `"dropped"` `"re_reading"` `"completed"`
 
         Raises
         -------------
         `ApiError`
         """
-        url = f"{self.URL}/manga/{id}/status"
-        URLRequest._request_url(url, "POST", params={"status" : status}, headers=self.bearer, timeout=self.timeout)
+        url = f"{self.URL}/manga/{manga_id}/status"
+        URLRequest.request_url(url, "POST", params={"status" : status}, headers=self.bearer, timeout=self.timeout)
 
-    def add_manga_to_customlist(self, id : str, listId :str) -> None:
+    def add_manga_to_customlist(self, manga_id : str, listId :str) -> None:
         """
         Adds a manga to a custom list
 
         Parameters
         --------------
-        id : `str`. The manga id
-        listId : `str`. The list id
+        id : `str`. The manga id.
+        listId : `str`. The list id.
         """
-        url = f"{self.URL}/{id}/list{listId}"
-        URLRequest._request_url(url, "POST", headers=self.bearer, timeout=self.timeout)
-    
-    def remove_manga_from_customlist(self, id : str, listId : str) -> None:
+        url = f"{self.URL}/{manga_id}/list{listId}"
+        URLRequest.request_url(url, "POST", headers=self.bearer, timeout=self.timeout)
+
+    def remove_manga_from_customlist(self, manga_id : str, listId : str) -> None:
         """
         Removes a manga from a custom list
 
@@ -722,8 +705,8 @@ class Api():
         id : `str`. The manga id
         listId : `str`. The list id
         """
-        url = f"{self.URL}/manga/{id}/list/{listId}"
-        URLRequest._request_url(url, "DELETE", headers=self.bearer, timeout=self.timeout)
+        url = f"{self.URL}/manga/{manga_id}/list/{listId}"
+        URLRequest.request_url(url, "DELETE", headers=self.bearer, timeout=self.timeout)
 
     def create_customlist(self, name : str, visibility : str = "public", manga : List[str] = None, version : int = 1) -> None:
         """
@@ -741,15 +724,15 @@ class Api():
         params = {"name" : name, "version" : version}
         params["visibility"] =  visibility
         params["manga[]"] = manga
-        URLRequest._request_url(url, "POST", params=params, timeout=self.timeout)
+        URLRequest.request_url(url, "POST", params=params, timeout=self.timeout)
 
-    def get_customlist(self, id : str, **kwargs) -> CustomList:
+    def get_customlist(self, custom_list_id : str, **kwargs) -> CustomList:
         """
         Get a custom list by its id
 
         Parameters
         ------------
-        id : `str`. The id of the custom list
+        custom_list_id : `str`. The id of the custom list
         limit : int
         offset : int
         translatedLanguage : List[str]
@@ -760,20 +743,20 @@ class Api():
         ------------
         `CustomList`
         """
-        url = f"{self.URL}/list/{id}"
-        resp = URLRequest._request_url(url, "GET", headers=self.bearer, timeout=self.timeout)
-        return CustomList._create_customlist(resp["result"])
-    
-    def update_customlist(self, id : str, **kwargs) -> CustomList:
+        url = f"{self.URL}/list/{custom_list_id}"
+        resp = URLRequest.request_url(url, "GET", headers=self.bearer,
+                                      timeout=self.timeout, params=kwargs)
+        return CustomList.ListFromDict(resp["result"])
+
+    def update_customlist(self, custom_list_id : str, **kwargs) -> CustomList:
         """
         Update a custom list
 
         Parameters
         ------------
-        id : `str`. The custom list id
+        custom_list_id : `str`. The custom list id
 
         ### QueryParams:
-
         name : `str`. The custom list name
         visibility : `str`. Values : `"public"` `"private"`
 
@@ -781,21 +764,22 @@ class Api():
         -----------
         `CustomList`
         """
-        url = f"{self.URL}/list/{id}"
-        resp = URLRequest._request_url(url, "PUT", params= kwargs, headers=self.bearer, timeout=self.timeout)
-        return CustomList._create_customlist(resp["result"])
-        
-    def delete_customlist(self, id : str) -> None:
+        url = f"{self.URL}/list/{custom_list_id}"
+        resp = URLRequest.request_url(url, "PUT", params= kwargs,
+                                    headers=self.bearer, timeout=self.timeout)
+        return CustomList.ListFromDict(resp["result"])
+
+    def delete_customlist(self, customlist_id : str) -> None:
         """
         Deletes a Custom List
 
         Parameters
         ------------
-        id : `str`. The custom list id
+        customlist_id : `str`. The custom list id
         """
-        url = f"{self.URL}/list{id}"
-        URLRequest._request_url(url, "DELETE", headers=self.bearer, timeout=self.timeout)
-    
+        url = f"{self.URL}/list{customlist_id}"
+        URLRequest.request_url(url, "DELETE", headers=self.bearer, timeout=self.timeout)
+
     def get_my_customlists(self, **kwargs) -> List[CustomList]:
         """
         Get my custom lists
@@ -803,7 +787,6 @@ class Api():
         Parameters
         ------------
         ### QueryParams:
-
         limit : `int`. The limit of custom lists to return
         offset : `int`. The amout of offset
 
@@ -812,19 +795,18 @@ class Api():
         `List[CustomList]`
         """
         url = f"{self.URL}/user/list"
-        resp = URLRequest._request_url(url, "GET", params=kwargs, headers=self.bearer, timeout=self.timeout)
-        return CustomList._create_customlist_list(resp)
+        resp = URLRequest.request_url(url, "GET", params=kwargs, headers=self.bearer, timeout=self.timeout)
+        return CustomList.create_customlist_list(resp)
 
-    def get_user_customlists(self, id : str, **kwargs) -> List[CustomList]:
+    def get_user_customlists(self, user_id : str, **kwargs) -> List[CustomList]:
         """
         Get a user's custom list. This will list only public custom lists
 
         Parameters
         ------------
-        id : `str`. the User id
+        user_id : `str`. the User id
 
         ### QueryParams:
-
         limit : `int`. The limit of custom lists to return
         offset : `int`. The amout of offset
 
@@ -832,38 +814,12 @@ class Api():
         ----------
         `List[CustomList]`
         """
-        url = f"{self.URL}/user/{id}/list"
-        resp = URLRequest._request_url(url, "GET", params=kwargs, headers=self.bearer, timeout=self.timeout)
-        return CustomList._create_customlist_list(resp)
-    
-    def get_customlist_manga_feed(self, id : str, **kwargs) -> List[Chapter]:
-        """
-        Get the chapter feed of a given custom list. 
-
-        Parameters
-        ------------
-        id : `str`. The custom list id
-
-        ### QueryParams:
-
-        limit : `int`. 
-        offset : `int`
-        translatedLanguage : `List[str]`. The translated laguages to query
-        createdAtSince : `str`. Datetime String with the following format YYYY-MM-DDTHH:MM:SS
-        updatedAtSince : `str`. Datetime String with the following format YYYY-MM-DDTHH:MM:SS
-        publishAtSince : `str`. Datetime String with the following format YYYY-MM-DDTHH:MM:SS
-
-        Returns
-        -----------
-        `List[Chapter]`
-        """
-        url = f"{self.URL}/user/{id}/feed"
-        resp = URLRequest._request_url(url, "GET", params=kwargs, headers=self.bearer, timeout = self.timeout)
-        return  Chapter._create_chapter_list(resp)
-
+        url = f"{self.URL}/user/{user_id}/list"
+        resp = URLRequest.request_url(url, "GET", params=kwargs, headers=self.bearer, timeout=self.timeout)
+        return CustomList.create_customlist_list(resp)
 
     @staticmethod
-    def _parse_coverart_params(params : Dict[str,str]) -> Dict[str, str]:
+    def __parse_coverart_params(params : Dict[str,str]) -> Dict[str, str]:
         if "manga" in params:
             params["manga[]"] = params.pop("manga")
         if "ids" in params:
@@ -878,20 +834,15 @@ class Api():
 
         Optional parameters
         -------------------------
-
         manga : List[str]. Manga ids
-        
         ids : List[str]. Cover ids
-
         uploaders : List[str]. User ids
-
         """
-
-        params = Api._parse_coverart_params(kwargs)
+        params = Api.__parse_coverart_params(kwargs)
         url = f"{self.URL}/cover"
-        resp = URLRequest._request_url(url, "GET", params = params, timeout= self.timeout)
-        return CoverArt._createCoverImageList(resp)
-    
+        resp = URLRequest.request_url(url, "GET", params = params, timeout= self.timeout)
+        return CoverArt.createCoverImageList(resp)
+
     def get_cover(self, coverId : str) -> CoverArt:
         """
         Gets a cover image
@@ -905,12 +856,12 @@ class Api():
         `CoverArt`. A cover art object
         """
         url = f"{self.URL}/cover/{coverId}"
-        resp = URLRequest._request_url(url, "GET", timeout=self.timeout)
-        return CoverArt._createCoverImage(resp)
-        
+        resp = URLRequest.request_url(url, "GET", timeout=self.timeout)
+        return CoverArt.CoverFromDict(resp)
+
     def upload_cover(self, manga_id : str, filename : str, ObjReturn : bool = False) -> Union[CoverArt, None]:
         """
-        Uploads a cover 
+        Uploads a cover
 
         Parameters
         --------------
@@ -926,8 +877,8 @@ class Api():
         with open(filename, 'rb') as f:
             file = f.read()
 
-        resp = URLRequest._request_url(url, "POST", params = {"file" : file}, headers= self.bearer, timeout=self.timeout)
-        return CoverArt._createCoverImage(resp) if ObjReturn else None
+        resp = URLRequest.request_url(url, "POST", params = {"file" : file}, headers= self.bearer, timeout=self.timeout)
+        return CoverArt.CoverFromDict(resp) if ObjReturn else None
 
     def edit_cover(self, coverId : str, description : str, volume : str = None, version : int = None, ObjReturn : bool = False) -> Union[None, CoverArt]:
         """
@@ -947,15 +898,15 @@ class Api():
         """
         if version is None:
             raise ValueError("Version cannot be null")
-        
+
         params = {"volume" : volume, "version" : version}
         if description is not None:
             params["description"] = description
 
         url = f"{self.URL}/cover/{coverId}"
-        resp = URLRequest._request_url(url, "PUT", params=params, headers=self.bearer, timeout=self.timeout)
-        return CoverArt._createCoverImage(resp) if ObjReturn else None
-    
+        resp = URLRequest.request_url(url, "PUT", params=params, headers=self.bearer, timeout=self.timeout)
+        return CoverArt.CoverFromDict(resp) if ObjReturn else None
+
     def delete_cover(self, coverId : Union[str , CoverArt]):
         """
         Deletes a cover
@@ -966,10 +917,10 @@ class Api():
         """
         if not coverId:
             raise ValueError("coverId cannot be empty")
-        if type(coverId) == CoverArt:
+        if isinstance(coverId, CoverArt):
             coverId = coverId.id
         url = f"{self.URL}/cover/{coverId}"
-        URLRequest._request_url(url, "DELETE", headers= self.bearer, timeout=self.timeout)
+        URLRequest.request_url(url, "DELETE", headers= self.bearer, timeout=self.timeout)
 
     def create_account(self, username : str, password : str, email : str, ObjReturn : bool = False) -> Union[User, None]:
         """
@@ -982,7 +933,7 @@ class Api():
         email : `str`.
         ObjReturn : `bool`.
 
-        Return
+        Returns
         -------------
         `User` if `ObjReturn` set to `True`
         """
@@ -990,13 +941,13 @@ class Api():
         email_regex = '^(\w|\.|\_|\-)+[@](\w|\_|\-|\.)+[.]\w{2,3}$' # regular expression for email
         if re.search(email_regex, email) is None:
             raise ValueError("The email provided is not valid")
-        
+
         if len(password) < 8:
             raise ValueError("Password must have at least 8 characters")
         params = {"username" : username, "password" : password, "email" : email}
-        resp = URLRequest._request_url(url, "POST", timeout=self.timeout, params=params)
-        return User._create_user(resp["data"]) if ObjReturn else None
-    
+        resp = URLRequest.request_url(url, "POST", timeout=self.timeout, params=params)
+        return User.UserFromDict(resp["data"]) if ObjReturn else None
+
     def activate_account(self, code : str):
         """
         Handles the activation code for the account creation
@@ -1006,8 +957,8 @@ class Api():
         code : `str`. The activation code sent to the email provided
         """
         url = f"{self.URL}/account/activate/{code}"
-        URLRequest._request_url(url, "GET", timeout=self.timeout)
-    
+        URLRequest.request_url(url, "GET", timeout=self.timeout)
+
     def resend_activation_code(self, email : str):
         """
         Resends the activation code to another email
@@ -1021,8 +972,8 @@ class Api():
             raise ValueError("The email provided is not valid")
         params = {"email" : email}
         url = f"{self.URL}/account/activate/resend"
-        URLRequest._request_url(url, "POST", timeout=self.timeout, params=params)
-    
+        URLRequest.request_url(url, "POST", timeout=self.timeout, params=params)
+
     def recover_account(self, email : str):
         """
         Recover an existing account
@@ -1036,7 +987,7 @@ class Api():
             raise ValueError("The email provided is not valid")
         params = {"email" : email}
         url = f"{self.URL}/account/recover"
-        URLRequest._request_url(url, "POST", params=params)
+        URLRequest.request_url(url, "POST", self.timeout, params)
 
     def complete_account_recover(self, code : str, newPassword : str):
         """
@@ -1051,4 +1002,4 @@ class Api():
             raise ValueError("Password must have at least 8 characters")
         url = f"{self.URL}/account/recover/{code}"
         params = {"newPassword" : newPassword}
-        URLRequest._request_url(url, "POST", timeout=self.timeout, params=params)
\ No newline at end of file
+        URLRequest.request_url(url, "POST", timeout=self.timeout, params=params)
