@@ -1,16 +1,13 @@
 import datetime
-
 from dateutil.parser import parse
-from future.utils import raise_with_traceback
-
-from typing import Dict, List, Union
-
-from mangadex import (MangaError, TagError, ChapterError, AuthorError, ScanlationGroupError, UserError, CustomListError, CoverArtError, URLRequest)
+from typing import Dict, List
+from mangadex import (MangaError, TagError, ChapterError, AuthorError, 
+                    ScanlationGroupError, UserError, CustomListError, CoverArtError, URLRequest)
 
 class Manga():
     def __init__(self) -> None:
 
-        self.id : str = ""
+        self.manga_id : str = ""
         self.title : Dict[str, str] = {}
         self.altTitles : Dict[str, str] = {}
         self.description : Dict[str, str] = {}
@@ -31,66 +28,70 @@ class Manga():
         self.artistId : List[str] = []
         self.coverId : str = ""
 
-    def _MangaFromDict(self, data : dict):
+    @classmethod
+    def MangaFromDict(cls, data : dict):
+
+        try:
+            data = data["data"]
+        except (TypeError, KeyError):
+            pass
+
         if data["type"] != 'manga' or not data:
             raise MangaError(data=data, message="The data probvided is not a Manga")
-        
+
         attributes = data["attributes"]
 
-        self.id = data["id"]
-        self.title = attributes["title"]
-        self.altTitles = attributes["altTitles"]
-        self.description = attributes["description"]
+        manga = cls()
+
+        manga.manga_id = data["id"]
+        manga.title = attributes["title"]
+        manga.altTitles = attributes["altTitles"]
+        manga.description = attributes["description"]
         try:
-            self.isLocked = attributes["isLocked"]
+            manga.isLocked = attributes["isLocked"]
         except KeyError:
             pass
         
-        self.links = attributes["links"]
-        self.originalLanguage = attributes["originalLanguage"]
-        self.lastVolume = attributes["lastVolume"]
-        self.lastChapter = attributes["lastChapter"]
-        self.publicationDemographic = attributes["publicationDemographic"]
-        self.status = attributes["status"]
-        self.year = attributes["year"]
-        self.contentRating = attributes["contentRating"]
-        self.tags = Tag._create_tag_list(attributes["tags"])
-        self.createdAt = parse(attributes["createdAt"])
-        self.updatedAt = parse(attributes["updatedAt"])
+        manga.links = attributes["links"]
+        manga.originalLanguage = attributes["originalLanguage"]
+        manga.lastVolume = attributes["lastVolume"]
+        manga.lastChapter = attributes["lastChapter"]
+        manga.publicationDemographic = attributes["publicationDemographic"]
+        manga.status = attributes["status"]
+        manga.year = attributes["year"]
+        manga.contentRating = attributes["contentRating"]
+        manga.tags = Tag.create_tag_list(attributes["tags"])
+        manga.createdAt = parse(attributes["createdAt"])
+        manga.updatedAt = parse(attributes["updatedAt"])
 
         for elem in data["relationships"]:
             if elem['type'] == 'author':
-                self.authorId.append(elem['id'])
+                manga.authorId.append(elem['id'])
             elif elem['type'] == 'artist':
-                self.artistId.append(elem['id'])
+                manga.artistId.append(elem['id'])
             elif elem['type'] == 'cover_art':
-                self.coverId = elem['id']
+                manga.coverId = elem['id']
 
-
-    @staticmethod
-    def _create_manga(elem) -> 'Manga':
-        manga = Manga()
-        manga._MangaFromDict(elem)
         return manga
-    
+
     @staticmethod
-    def _create_manga_list(resp) -> List['Manga']:
+    def create_manga_list(resp) -> List['Manga']:
         resp = resp["data"]
         manga_list = []
         for elem in resp:
-            manga_list.append(Manga._create_manga(elem))
+            manga_list.append(Manga.MangaFromDict(elem))
         return manga_list
 
     def __eq__(self, other : 'Manga') -> bool:
-        my_vals = [self.id, self.title, self.createdAt, self.authorId]
-        other_vals = [other.id, other.title, other.createdAt, other.authorId]
+        my_vals = [self.manga_id, self.title, self.createdAt, self.authorId]
+        other_vals = [other.manga_id, other.title, other.createdAt, other.authorId]
         return all((me == other for me, other in zip(my_vals, other_vals)))
-    
+
     def __ne__(self, other: object) -> bool:
         return not self.__eq__(other)
 
     def __repr__(self) -> str:
-        temp1 = f"Manga(id = {self.id}, title = {self.title}, altTitles = {self.altTitles}, description = {self.description}, isLocked = {self.isLocked}, links = {self.links}, originalLanguage = {self.originalLanguage} \n"
+        temp1 = f"Manga(id = {self.manga_id}, title = {self.title}, altTitles = {self.altTitles}, description = {self.description}, isLocked = {self.isLocked}, links = {self.links}, originalLanguage = {self.originalLanguage} \n"
         temp2 = f"lastVolume = {self.lastVolume}, lastChapter = {self.lastChapter}, publicationDemographic = {self.publicationDemographic}, status = {self.status}, year = {self.year}, contentRating = {self.contentRating} \n"
         temp3 = f"createdAt = {self.createdAt}, uploadedAt = {self.updatedAt}), authorId = {self.authorId}, artistId = {self.artistId}, coverId = {self.coverId}"
         return temp1 + temp2 + temp3
@@ -102,8 +103,9 @@ class Tag():
         self.description : str = ""
         self.group : str = ""
 
-    def _TagFromDict(self, data : dict):
-        
+    @classmethod
+    def TagFromDict(cls, data : dict) -> 'Tag':
+        tag = cls()
         try:
             data = data["data"]
         except KeyError:
@@ -111,25 +113,26 @@ class Tag():
 
         if data["type"] != 'tag' or not data:
             raise TagError(data=data, message="The data provided is not a Tag")
-        
+
         attributes = data["attributes"]
 
-        self.id = data["id"]
-        self.name = attributes["name"]
-        self.description = attributes["description"]
-        self.group = attributes["group"]
+        tag.id = data["id"]
+        tag.name = attributes["name"]
+        tag.description = attributes["description"]
+        tag.group = attributes["group"]
 
-    @staticmethod
-    def _create_tag(elem) -> 'Tag':
-        tag = Tag()
-        tag._TagFromDict(elem)
         return tag
 
     @staticmethod
-    def _create_tag_list(resp) -> List['Tag']:
+    def create_tag_list(resp) -> List['Tag']:
         tag_list = []
-        for tag in resp["data"]:
-            tag_list.append(Tag._create_tag(tag))
+        try:
+            resp = resp["data"]
+        except (TypeError, KeyError):
+            pass
+
+        for tag in resp:
+            tag_list.append(Tag.TagFromDict(tag))
         return tag_list
 
     def __eq__(self, other : 'Tag') -> bool:
@@ -158,37 +161,44 @@ class Chapter():
         self.createdAt : datetime = ""
         self.updatedAt : datetime = ""
         self.publishAt : datetime = ""
-    
-    def _ChapterFromDict(self, data):
+        
 
+    @classmethod
+    def ChapterFromDict(cls, data) -> 'Chapter':
+        chapter = cls()
         try:
             data = data["data"]
         except KeyError:
             pass
 
         if data["type"] != 'chapter' or not data:
-            raise ChapterError(data = data, mmessage="The data provided is not a Chapter")
+            raise ChapterError(data = data, message="The data provided is not a Chapter")
 
         attributes = data["attributes"]
 
-        self.id = data["id"]
-        self.title = attributes["title"]
-        self.volume = attributes["volume"]
-        self.chapter = float(attributes["chapter"]) if attributes['chapter'] is not None else None
-        self.translatedLanguage = attributes["translatedLanguage"]
-        self.hash = attributes["hash"]
-        self.data = attributes["data"]
-        self.publishAt = parse(attributes["publishAt"])
-        self.createdAt = parse(attributes["createdAt"])
-        self.updatedAt = parse(attributes["updatedAt"])
-        self.scanlation_group_id = data["relationships"][0]["id"]
-        self.Mangaid = data["relationships"][1]["id"]
-        self.uploader = data["relationships"][2]["id"]
+        chapter.id = data["id"]
+        chapter.title = attributes["title"]
+        chapter.volume = attributes["volume"]
+        chapter.chapter = float(attributes["chapter"]) if attributes['chapter'] is not None else None
+        chapter.translatedLanguage = attributes["translatedLanguage"]
+        # chapter.hash = attributes["hash"]
+        # chapter.data = attributes["data"]
+        chapter.publishAt = parse(attributes["publishAt"])
+        chapter.createdAt = parse(attributes["createdAt"])
+        chapter.updatedAt = parse(attributes["updatedAt"])
+        chapter.scanlation_group_id = data["relationships"][0]["id"]
+        chapter.Mangaid = data["relationships"][1]["id"]
+        try:
+            chapter.uploader = data["relationships"][2]["id"]
+        except IndexError:
+            pass
+
+        return chapter
 
     def fetch_chapter_images(self) -> List[str]: #maybe make this an async function?
         """
         Get the image links for the chapter
-        
+
         Returns
         -----------
         `List[str]`. A list with the links with the chapter images
@@ -200,7 +210,9 @@ class Chapter():
         `ApiError`
         """
         url = f"https://api.mangadex.org/at-home/server/{self.id}"
-        image_server_url = URLRequest._request_url(url, "GET", timeout=5)
+        image_server_url = URLRequest.request_url(url, "GET", timeout=5)
+        self.hash = image_server_url["chapter"]["hash"]
+        self.data = image_server_url["chapter"]["data"]
         image_server_url = image_server_url["baseUrl"].replace("\\", "")
         image_server_url = f"{image_server_url}/data"
         image_urls = []
@@ -210,22 +222,16 @@ class Chapter():
         return image_urls
 
     @staticmethod
-    def _create_chapter(elem) -> 'Chapter':
-        chap = Chapter()
-        chap._ChapterFromDict(elem)
-        return chap
-    
-    @staticmethod
-    def _create_chapter_list(resp) -> List['Chapter']:
+    def create_chapter_list(resp) -> List['Chapter']:
         resp = resp["data"]
         chap_list = []
         for elem in resp:
-            chap_list.append(Chapter._create_chapter(elem))
+            chap_list.append(Chapter.ChapterFromDict(elem))
         return chap_list
 
     def __eq__(self, other: 'Chapter') -> bool:
-        my_vals = [self.id, self.hash, self.Mangaid, self.chapter]
-        other_vals = [other.id, other.hash, other.Mangaid, other.chapter]
+        my_vals = [self.id, self.Mangaid, self.chapter]
+        other_vals = [other.id, other.Mangaid, other.chapter]
         return all((me == other for me,other in zip(my_vals, other_vals)))
 
     def __ne__(self, other: 'Chapter') -> bool:
@@ -240,8 +246,8 @@ class User():
     def __init__(self) -> None:
         self.id : str = ""
         self.username :str = ""
-
-    def _UserFromDict(self, data):
+    @classmethod
+    def UserFromDict(cls, data) -> 'User':
         if "data" in data:
             data = data["data"]
 
@@ -250,21 +256,18 @@ class User():
         
         attributes = data["attributes"]
 
-        self.id = data["id"]
-        self.username = attributes["username"]
+        user = cls()
+        user.id = data["id"]
+        user.username = attributes["username"]
 
-    @staticmethod
-    def _create_user(elem) -> 'User':
-        user = User()
-        user._UserFromDict(elem)
         return user
 
     @staticmethod    
-    def _create_user_list(resp) -> List['User']:
+    def create_user_list(resp) -> List['User']:
         resp = resp["data"]
         user_list = []
         for elem in resp:
-            user_list.append(User._create_user(elem))
+            user_list.append(User.UserFromDict(elem))
         return user_list
 
     def __eq__(self, other: 'User') -> bool:
@@ -287,8 +290,8 @@ class Author():
         self.createdAt : datetime = ""
         self.updatedAt : datetime = ""
         self.mangas : List[str] = []
-    
-    def _AuthorFromDict(self, data):
+    @classmethod
+    def AuthorFromDict(cls, data):
 
         try:
             data = data["data"]
@@ -297,29 +300,27 @@ class Author():
 
         if data["type"] != "author" or not data:
             raise AuthorError(data = data, message= f"The data provided is not Author is : {data['type']}")
-    
+
+        author = cls()
+
         attributes = data["attributes"]
 
-        self.id = data["id"]
-        self.name = attributes["name"]
-        self.imageUrl = attributes["imageUrl"]
-        self.bio = attributes["biography"]
-        self.createdAt = parse(attributes["createdAt"])
-        self.updatedAt = parse(attributes["updatedAt"])
-        self.mangas =  [manga["id"] for manga in data["relationships"] if manga["type"] == "manga"] # better keep it like this to not consume computing time
+        author.id = data["id"]
+        author.name = attributes["name"]
+        author.imageUrl = attributes["imageUrl"]
+        author.bio = attributes["biography"]
+        author.createdAt = parse(attributes["createdAt"])
+        author.updatedAt = parse(attributes["updatedAt"])
+        author.mangas =  [manga["id"] for manga in data["relationships"] if manga["type"] == "manga"] # better keep it like this to not consume computing time
 
-    @staticmethod
-    def _create_author(elem) -> 'Author':
-        author = Author()
-        author._AuthorFromDict(elem)
         return author
 
     @staticmethod
-    def _create_authors_list(self, resp) -> List['Author']:
+    def create_authors_list(resp) -> List['Author']:
         resp = resp["data"]
         authors_list = []
         for elem in resp:
-            authors_list.append(Author._create_author(elem))
+            authors_list.append(Author.AuthorFromDict(elem))
         return authors_list
 
     def __eq__(self, other: 'Author') -> bool:
@@ -341,15 +342,18 @@ class ScanlationGroup():
         self.createdAt : datetime = None
         self.updatedAt : datetime = None
 
-    def _ScanlationFromDict(self, data):
-        
+    @classmethod
+    def ScanlationFromDict(cls, data) -> 'ScanlationGroup':
+
         if data["type"] != "scanlation_group" or not data:
-            raise ScanlationGroupError("The data provided is not an scanlation group")
+            raise ScanlationGroupError(data,"The data provided is not an scanlation group")
+
+        scan_group = cls()
 
         attributes = data["attributes"]
         relationships = data["relationships"]
-        self.id = data["id"]
-        self.name = attributes["name"]
+        scan_group.id = data["id"]
+        scan_group.name = attributes["name"]
 
         leader = User()
         for elem in relationships:
@@ -360,31 +364,26 @@ class ScanlationGroup():
             except KeyError:
                 continue
 
-        # leader.username = attributes["leader"]["attributes"]["username"] #didn't use the _UserFromDict method becasue the api response is different
-        self.leader =  leader
+        scan_group.leader =  leader
 
-        self.createdAt = parse(attributes["createdAt"])
-        self.updatedAt = parse(attributes["updatedAt"])
-    
-    @staticmethod
-    def _create_group(elem) ->  'ScanlationGroup':
-        group = ScanlationGroup()
-        group._ScanlationFromDict(elem)
-        return group
+        scan_group.createdAt = parse(attributes["createdAt"])
+        scan_group.updatedAt = parse(attributes["updatedAt"])
+
+        return scan_group
 
     @staticmethod
-    def _create_group_list(resp) -> List['ScanlationGroup']:
+    def create_group_list(resp) -> List['ScanlationGroup']:
         resp = resp["data"]
         group_list = []
         for elem in resp:
-            group_list.append(ScanlationGroup._create_group(elem))
-        return group_list  
+            group_list.append(ScanlationGroup.ScanlationFromDict(elem))
+        return group_list
 
     def __eq__(self, other: 'ScanlationGroup') -> bool:
         my_vals = []
         other_vals = []
         return all((me == other for me,other in zip(my_vals, other_vals)))
-    
+
     def __ne__(self, other: 'ScanlationGroup') -> bool:
         return not self.__eq__(other)
         
@@ -396,33 +395,36 @@ class CustomList():
         self.id : str = ""
         self.name : str = ""
         self.visibility : str = ""
-        self.owner : User = None
-        self.mangas : List[Manga] = None
+        self.owner : str = ""
+        self.mangas : List[str] = []
 
-    def _ListFromDict(self, data):
+    @classmethod
+    def ListFromDict(cls, data):
         if data["type"] != "custom_list" or not data:
-            raise CustomListError("The data provided is not a Custom List")
-        
+            raise CustomListError(data,"The data provided is not a Custom List")
+
+        custom_list = cls()
+
         attributes = data["attributes"]
+        relationships = data["relationships"]
+
+        custom_list.id = data["id"]
+        custom_list.name = attributes["name"]
+        custom_list.visibility = attributes["visibility"]
+        for elem in relationships:
+            if elem["type"] == "user":
+                custom_list.owner = elem["id"]
+            elif elem["type"] == "manga":
+                custom_list.mangas.append(elem["id"])
 
-        self.id = data["id"]
-        self.name = attributes["name"]
-        self.visibility = attributes["visibility"]
-        self.owner = User()
-        self.owner._UserFromDict(attributes["owner"])
-    
-    @staticmethod
-    def _create_customlist(elem) -> 'CustomList':
-        custom_list = CustomList()
-        custom_list._ListFromDict(elem)
         return custom_list
 
     @staticmethod
-    def _create_customlist_list(resp) -> List['CustomList']:
+    def create_customlist_list(resp) -> List['CustomList']:
         resp = resp["data"]
         custom_lists = []
         for elem in resp:
-            custom_lists.append(CustomList._create_customlist(elem))
+            custom_lists.append(CustomList.ListFromDict(elem))
         return custom_lists
 
     def __repr__(self) -> str:
@@ -438,19 +440,30 @@ class CoverArt():
         self.updatedAt : datetime = None
         self.mangaId : str = None
 
-    def _CoverFromDict(self, data):
+    @classmethod
+    def CoverFromDict(cls, data) -> 'CoverArt':
+
+        try:
+            data = data["data"]
+        except (KeyError, TypeError):
+            pass
+
         if data["type"] != "cover_art" or not data:
-            raise CoverArtError("The data provided is not a Custom List")
-        
+            raise CoverArtError(data, "The data provided is not a Custom List")
+
+        cover = cls()
+
         attributes = data["attributes"]
 
-        self.id = data["id"]
-        self.volume = attributes["volume"]
-        self.fileName = attributes["fileName"]
-        self.description = attributes["description"]
-        self.createdAt = parse(attributes["createdAt"])
-        self.updatedAt = parse(attributes["updatedAt"])
-        self.mangaId = data["relationships"][0]["id"]
+        cover.id = data["id"]
+        cover.volume = attributes["volume"]
+        cover.fileName = attributes["fileName"]
+        cover.description = attributes["description"]
+        cover.createdAt = parse(attributes["createdAt"])
+        cover.updatedAt = parse(attributes["updatedAt"])
+        cover.mangaId = data["relationships"][0]["id"]
+
+        return cover
     
     def fetch_cover_image(self, quality : str = "source") -> str:
         """
@@ -465,27 +478,23 @@ class CoverArt():
         url : `str`. The cover url
         """
         url = f"https://uploads.mangadex.org/covers/{self.mangaId}/{self.fileName}"
-        
+
         if quality == "medium":
             url = f"{url}.512.jpg"
         elif quality == "small":
             url = f"{url}.256.jpg"
-        
+
         return url
 
     @staticmethod
-    def _createCoverImage(elem) -> 'CoverArt':
-        coverImage = CoverArt()
-        coverImage._CoverFromDict(elem)
-        return coverImage
-
-    @staticmethod
-    def _createCoverImageList(resp) -> List['CoverArt']:
+    def createCoverImageList(resp) -> List['CoverArt']:
         resp = resp["data"]
         coverimage_list = []
         for elem in resp:
-            coverimage_list.append(CoverArt._createCoverImage(elem))
+            coverimage_list.append(CoverArt.CoverFromDict(elem))
         return coverimage_list
 
     def __repr__(self) -> str:
-        return f"CoverArt(id = {self.id}, mangaId = {self.mangaId}, volume = {self.volume}, fileName = {self.fileName}, description = {self.description}, createdAt = {self.createdAt}, updatedAt = {self.updatedAt})"
\ No newline at end of file
+        return f"CoverArt(id = {self.id}, mangaId = {self.mangaId}, volume = {self.volume}, \
+                fileName = {self.fileName}, description = {self.description}, \
+                createdAt = {self.createdAt}, updatedAt = {self.updatedAt})"
\ No newline at end of file
