@@ -1,5 +1,8 @@
-import requests
+"""
+Url handler module
+"""
 import json
+import requests
 
 from mangadex import ApiError
 
@@ -15,14 +18,20 @@ except ImportError:
     from urllib import urlencode
 
 class URLRequest():
+    """
+    Handles the request to the server
+    """
     @staticmethod
-    def _request_url(url, method, timeout, params = None, headers = None) -> dict:
+    def request_url(url, method, timeout, params = None, headers = None) -> dict:
+        """
+        The handler fot GET, POST, PUT and DEL
+        """
         if params is None:
             params = {}
         params = {k: v.decode("utf-8") if isinstance(v, bytes) else v for k, v in params.items()}
-        
+
         if method == "GET":
-            url = URLRequest._build_url(url, params)
+            url = URLRequest.__build_url(url, params)
             try:
                 resp = requests.get(url, headers=headers, timeout= timeout)
             except requests.RequestException as e:
@@ -48,19 +57,19 @@ class URLRequest():
                 raise
         if not resp.ok:
             raise ApiError(resp)
-            
+
         content = resp.content
-        data = URLRequest._parse_data(content if isinstance(content, basestring) else content.decode('utf-8'))
+        data = URLRequest.__parse_data(content if isinstance(content, basestring) else content.decode('utf-8'))
         return data
 
     @staticmethod
-    def _build_url(url, params) -> str:
+    def __build_url(url, params) -> str:
         if params and len(params) > 0:
-            url = url + '?' + URLRequest._encode_parameters(params)
+            url = url + '?' + URLRequest.__encode_parameters(params)
         return url
-    
+
     @staticmethod
-    def _encode_parameters(params) -> str:
+    def __encode_parameters(params) -> str:
         if params is None:
             return None
         else:
@@ -76,21 +85,21 @@ class URLRequest():
             return urlencode(params_tuple)
 
     @staticmethod
-    def _parse_data(content):
+    def __parse_data(content):
         try:
             data = json.loads(content)
             URLRequest._check_api_error(data)
         except:
-            raise    
+            raise
         return data
 
     @staticmethod
-    def _check_api_error(data : dict): 
-        if type(data) == list:
+    def _check_api_error(data : dict):
+        if isinstance(data, list):
             data = data[0]
         if "result" in data.keys():
             if data['result'] == 'error' or 'error' in data:
                 raise ApiError(data['errors'])
             if isinstance(data, (list, tuple)) and len(data) > 0:
                 if 'error' in data:
-                    raise ApiError(data['errors'])
\ No newline at end of file
+                    raise ApiError(data['errors'])
